-- First, we create a namespace for our addon by declaring a top-level table that will hold everything else.
RemiCustomAddon = {}
 
-- This isn't strictly necessary, but we'll use this string later when registering events.
-- Better to define it in a single place rather than retyping the same string.
RemiCustomAddon.name = "RemiCustomAddon"

local logger = LibDebugLogger.Create("RemiCustomAddon")

function RemiCustomAddon:RestorePositionBagSpace()
    local bagIndicator = GetControl(self.control, "BagIndicator");

    local leftBagSpace = self.savedVariables.leftBagSpace
    local topBagSpace = self.savedVariables.topBagSpace
   
    bagIndicator:ClearAnchors()
    bagIndicator:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, leftBagSpace, topBagSpace)
end

function RemiCustomAddon:RestorePositionFight()
    local fightIndicator = GetControl(self.control, "FightIndicator");

    local leftFight = self.savedVariables.leftFight
    local topFight = self.savedVariables.topFight
   
    fightIndicator:ClearAnchors()
    fightIndicator:SetAnchor(TOPLEFT, GuiRoot, TOPLEFT, leftFight, topFight)
end

function RemiCustomAddon:Initialize(control)
    -- You can now grab child elements of your top level control without worrying about the full global names.
    local bagIndicator = GetControl(control, "BagIndicator");
    local fightIndicator = GetControl(control, "FightIndicator");
 
    self.inCombat = IsUnitInCombat("player");
    self.control = control;
    
    EVENT_MANAGER:RegisterForEvent(self.name, EVENT_PLAYER_COMBAT_STATE, self.OnPlayerCombatState)
    EVENT_MANAGER:RegisterForEvent(self.name, EVENT_GROUPING_TOOLS_READY_CHECK_UPDATED, self.OnLFGReadyCheckState)
    EVENT_MANAGER:RegisterForEvent(self.name, EVENT_PLAYER_ACTIVATED, self.DoesBagHaveSpace)
 
    -- Bind the addon load from here.
    EVENT_MANAGER:RegisterForEvent(RemiCustomAddon.name, EVENT_ADD_ON_LOADED, RemiCustomAddon.OnAddOnLoaded)
 
    -- Shouldn't need this call because you also bound it to PLAYER_ACTIVATED, but I included it because you had it in the xml originally
    self.DoesBagHaveSpace()
    self.OnPlayerCombatState()

    self.savedVariables = ZO_SavedVars:New("RemiCustomAddonSavedVariables", 1, nil, {})
    self:RestorePositionBagSpace()
    self:RestorePositionFight()
end

-- old
-- Next we create a function that will initialize our addon
--function RemiCustomAddon:Initialize()
--    self.inCombat = IsUnitInCombat("player");
--    
--
--    EVENT_MANAGER:RegisterForEvent(self.name, EVENT_PLAYER_COMBAT_STATE, self.OnPlayerCombatState)
--    EVENT_MANAGER:RegisterForEvent(self.name, EVENT_GROUPING_TOOLS_READY_CHECK_UPDATED, self.OnLFGReadyCheckState)
--    EVENT_MANAGER:RegisterForEvent(self.name, EVENT_PLAYER_ACTIVATED, self.DoesBagHaveSpace)
--
--    self.savedVariables = ZO_SavedVars:New("RemiCustomAddonSavedVariables", 1, nil, {})
--end

function RemiCustomAddon.DoesBagHaveSpace(eventCode, initial)
    local bagIndicator = GetControl(self.control, "BagIndicator");

    itemSpace = GetNumBagFreeSlots(1)
    if itemSpace < 10 then
        bagIndicator:SetHidden(false)
        GetControl(bagIndicator, "Label"):SetText("Your bag is almost full! " + tostring(itemSpace) + "/" + tostring(GetBagUseableSize()))
    else
        bagIndicator:SetHidden(false)
        GetControl(bagIndicator, "Label"):SetText("Bag capacity: " + tostring(itemSpace) + "/" + tostring(GetBagUseableSize()))
   end
end

function RemiCustomAddon.OnLFGReadyCheckState(event)
    if HasLFGReadyCheckNotification() then
        AcceptLFGReadyCheckNotification()
    end
end

function RemiCustomAddon.OnPlayerCombatState(event, inCombat)
    local fightIndicator = GetControl(self.control, "FightIndicator");

    fightIndicator:SetHidden(not IsUnitInCombat('player'))
    -- The ~= operator is "not equal to" in Lua.
    if inCombat ~= RemiCustomAddon.inCombat then
      -- The player's state has changed. Update the stored state...
      RemiCustomAddon.inCombat = inCombat
   
      -- ...and then update the control.
      fightIndicator:SetHidden(not inCombat)
    end
end

function RemiCustomAddon.OnIndicatorMoveStopFight()
    local fightIndicator = GetControl(self.control, "FightIndicator");

    RemiCustomAddon.savedVariables.leftFight = fightIndicator:GetLeft()
    RemiCustomAddon.savedVariables.topFight = fightIndicator:GetTop()
end

function RemiCustomAddon.OnIndicatorMoveStopBagSpace()
    local bagIndicator = GetControl(self.control, "BagIndicator");

    RemiCustomAddon.savedVariables.leftBagSpace = bagIndicator:GetLeft()
    RemiCustomAddon.savedVariables.topBagSpace = bagIndicator:GetTop()
end

-- old
---- Then we create an event handler function which will be called when the "addon loaded" event
---- occurs. We'll use this to initialize our addon after all of its resources are fully loaded.
--function RemiCustomAddon.OnAddOnLoaded(event, addonName)
--  -- The event fires each time *any* addon loads - but we only care about when our own addon loads.
--  if addonName == RemiCustomAddon.name then
--    RemiCustomAddon:Initialize()
--  end
--end
-- 
---- Finally, we'll register our event handler function to be called when the proper event occurs.
--EVENT_MANAGER:RegisterForEvent(RemiCustomAddon.name, EVENT_ADD_ON_LOADED, RemiCustomAddon.OnAddOnLoaded)